[PATCH v2 07/10] binman: Add gzip bintool

Stefan Herbrechtsmeier stefan.herbrechtsmeier-oss at weidmueller.com
Mon Aug 8 12:51:22 CEST 2022


From: Stefan Herbrechtsmeier <stefan.herbrechtsmeier at weidmueller.com>

Add gzip bintool to binman to support on-the-fly compression of Linux
kernel images and FPGA bitstreams. The SPL basic fitImage implementation
supports only gzip decompression.

Signed-off-by: Stefan Herbrechtsmeier <stefan.herbrechtsmeier at weidmueller.com>

---

Changes in v2:
- Added

 tools/binman/btool/gzip.py | 31 +++++++++++++++++++++++++++++++
 tools/binman/comp_util.py  | 16 +++++++++-------
 2 files changed, 40 insertions(+), 7 deletions(-)
 create mode 100644 tools/binman/btool/gzip.py

diff --git a/tools/binman/btool/gzip.py b/tools/binman/btool/gzip.py
new file mode 100644
index 0000000000..0d75028120
--- /dev/null
+++ b/tools/binman/btool/gzip.py
@@ -0,0 +1,31 @@
+# SPDX-License-Identifier: GPL-2.0+
+# Copyright (C) 2022 Weidmüller Interface GmbH & Co. KG
+# Stefan Herbrechtsmeier <stefan.herbrechtsmeier at weidmueller.com>
+#
+"""Bintool implementation for gzip
+
+gzip allows compression and decompression of files.
+
+Documentation is available via::
+
+   man gzip
+"""
+
+from binman import bintool
+
+# pylint: disable=C0103
+class Bintoolgzip(bintool.BintoolPacker):
+    """Compression/decompression using the gzip algorithm
+
+    This bintool supports running `gzip` to compress and decompress data, as
+    used by binman.
+
+    It is also possible to fetch the tool, which uses `apt` to install it.
+
+    Documentation is available via::
+
+        man gzip
+    """
+    def __init__(self, name):
+        super().__init__(name, compress_args=[],
+                         version_regex=r'gzip ([0-9.]+)')
diff --git a/tools/binman/comp_util.py b/tools/binman/comp_util.py
index fa75911e58..4fbd80e2ff 100644
--- a/tools/binman/comp_util.py
+++ b/tools/binman/comp_util.py
@@ -11,7 +11,7 @@ from binman import bintool
 from patman import tools
 
 # Supported compressions
-COMPRESSIONS = ['bzip2', 'lz4', 'lzma']
+COMPRESSIONS = ['bzip2', 'gzip', 'lz4', 'lzma']
 
 bintools = {}
 
@@ -34,12 +34,13 @@ def compress(indata, algo):
     Note that for lzma this uses an old version of the algorithm, not that
     provided by xz.
 
-    This requires 'bzip2', 'lz4' and 'lzma_alone' tools. It also requires an
-    output directory to be previously set up, by calling PrepareOutputDir().
+    This requires 'bzip2', 'gzip', 'lz4' and 'lzma_alone' tools. It also
+    requires an output directory to be previously set up, by calling
+    PrepareOutputDir().
 
     Args:
         indata (bytes): Input data to compress
         algo (str): Algorithm to use ('none', 'bzip2', 'lz4' or 'lzma')
 
     Returns:
         bytes: Compressed data
@@ -60,12 +61,13 @@ def decompress(indata, algo):
     Note that for lzma this uses an old version of the algorithm, not that
     provided by xz.
 
-    This requires 'bzip2', 'lz4' and 'lzma_alone' tools. It also requires an
-    output directory to be previously set up, by calling PrepareOutputDir().
+    This requires 'bzip2', 'gzip', 'lz4' and 'lzma_alone' tools. It also
+    requires an output directory to be previously set up, by calling
+    PrepareOutputDir().
 
     Args:
         indata (bytes): Input data to decompress
         algo (str): Algorithm to use ('none', 'bzip2', 'lz4' or 'lzma')
 
     Returns:
         (bytes) Compressed data
@@ -34,12 +34,13 @@ def compress(indata, algo):
     Args:
         indata (bytes): Input data to compress
-        algo (str): Algorithm to use ('none', 'bzip2', 'lz4' or 'lzma')
+        algo (str): Algorithm to use ('none', 'bzip2', 'gzip', 'lz4' or 'lzma')
 
     Returns:
@@ -60,12 +61,13 @@ def decompress(indata, algo):
     Args:
         indata (bytes): Input data to decompress
-        algo (str): Algorithm to use ('none', 'bzip2', 'lz4' or 'lzma')
+        algo (str): Algorithm to use ('none', 'bzip2', 'gzip', 'lz4' or 'lzma')
 
     Returns:
-- 
2.30.2



More information about the U-Boot mailing list